@@ -7,6 +7,11 @@ from cx_releaser.scripts.rollback import args as rollback_args, rollback
 def main():
     parser = ArgumentParser()
     parser.add_argument('--tenant', help='Name of tenant (AWS account id) to perform operation')
+    parser.add_argument('--images', help='List of images. Could be local_image;remote_image.'
+                                         'If local image not specified will be set to remote_image',
+                        required=True)
+    parser.add_argument('--on_tag_exist', help='replace or raise if tag already exist',
+                        choices=['replace', 'raise'])
     parser.add_argument('--all_tenants', action='store_true', help='If passed perform operation on all tenants')
     parser.add_argument('--version', help='Version of release')
     parser.add_argument('--local_version', help='Tag of local image to make release for')
@@ -15,12 +20,13 @@ def main():
     rollback_args(subparsers), push_args(subparsers)
     args = parser.parse_args()
     if args.command == 'push':
-        push(args.tenant, args.version, args.config_path,
-             args.equal_tags, all_tenants=args.all_tenants, local_version=args.local_version,
-             auto_incr_version=args.auto_incr_version)
+        push(args.tenant, args.version, args.config_path, images=args.images.split('-'),
+             equal_tags=args.equal_tags, all_tenants=args.all_tenants, local_version=args.local_version,
+             auto_incr_version=args.auto_incr_version,
+             on_repository_not_exist=args.on_repository_not_exist)
     elif args.command == 'rollback':
         rollback(args.tenant, args.version, args.config_path,
-                 args.prev_release,
+                 prev_release_version=args.prev_release, images=args.images.split('-'),
                  all_tenants=args.all_tenants,
                  local_version=args.local_version,
                  delete_all_equal_tags=args.all_tags)
